# dupesearch

A fast and simple command line tool written in rust and python for finding duplicate files.

## Should I use it?

Probably not, this is still a WIP, it's quite messy, hasn't been tested much, and was my first time using Rust so I probably did some dodgy stuff.

## How do I use it?

1) Install the `dupesearch` package from pip using your preferred command.
2) Run `python -m dupesearch -i` and follow the instructions.

## Contributions

If you'd like to make a contribution, feel free to and i'll try to merge it in. If it's not a tiny change please create an issue first, at least to ensure that i'm still active and able to review the changes.

Any issues suggesting improvements are also welcome, although this was just done as a practice project to get started with rust and packaging python projects, so I may not implement every suggestion.